# Calibrate the pedal clock
# -------------------------
# Instructions:
# 1. Ensure the pedal is not connected to a USB cable.
# 2. Power up the pedal with the tap tempo switch pressed.
# 3. The LED should be flashing yellow.  If not, contact RounderSounds.
# 4. Using a reliable stopwatch, start the stopwatch at the same time as clicking the wave|edit knob down.
# 5. The LED should now be solid yellow.
# 6. When the stopwatch reaches 1 hour exactly, click the wave|edit knob down again.
# 7. The LED should now be solid green.  If not, contact RounderSounds.

# magenta = can't write files
# blue = waiting for start
# yellow = waiting for end
# green = file written
# red = error being displayed

CANNOT_WRITE = (255, 0, 255)
WAITING_FOR_START = (0, 0, 255)
TIMING = (255, 255, 0)
FILE_WRITTEN = (0, 255, 0)
ERROR = (255, 0, 0)

import board, time, os
from adafruit_debouncer import Debouncer
from adafruit_dotstar import DotStar
import i2c_rotary_encoder as _rei2c

dotStar = DotStar(board.APA102_SCK, board.APA102_MOSI, 1)
rotaryEncoder = _rei2c.I2CRotaryEncoder()
editPin = Debouncer(rotaryEncoder.GetButton())

waiting = True
timing = False
startTime = None
endTime = None

def CanWrite():
    testFileName = "/test_writeable.txt"
    canWrite = False
    try:
        with open(testFileName, "w") as fp:
            fp.write('# This file has been created to test that the file system is writable.\n')
            fp.write('# It should only exist for a very brief time.\n')
            fp.flush()
        fp.close()
        canWrite = True
    except:
        return False
    canDelete = False
    try:
        os.remove(testFileName)
        canDelete = True
    except:
        canDelete = False
    return canWrite and canDelete

def WriteTime(elapsedTime):
    calibrationFileName = "/clock_calibration"
    try:
        with open(calibrationFileName, "w") as fp:
            fp.write('# This file contains important configuration information.\n')
            fp.write('# Do not alter or remove it.\n')
            fp.write(str(elapsedTime) + '\n')
            fp.flush()
        fp.close()
        return True
    except:
        return False

if not CanWrite():
    dotStar[0] = CANNOT_WRITE
    print("cannot write files")
else:
    dotStar[0] = WAITING_FOR_START
    print("waiting for timer to be started")
    while waiting:
        editPin.update()
        if editPin.fell:
            startTime = time.monotonic()
            print("started timing at", startTime)
            dotStar[0] = TIMING
            waiting = False
            timing = True
    while timing:
        editPin.update()
        if editPin.fell:
            endTime = time.monotonic()
            print("ended timing at", endTime)
            if WriteTime(endTime - startTime):
                print("file written")
                dotStar[0] = FILE_WRITTEN
                timing = False
            else:
                print("error")
                dotStar[0] = ERROR
                timing = False

while True:
    time.sleep(10)